==> spellathon-5.21.tar.gz: spellathon-5.21/src/gui/lineeditwc_widget.h <==
/*
 * Copyright (c) 2008, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the <ORGANIZATION> nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef _LEWC_
#define _LEWC_

#include <QObject>
#include <QWidget>
#include <QLineEdit>
#include <QPainter>
#include <QKeyEvent>
#include <QPaintEvent>
#include <QMouseEvent>
#include <QTimer>

class LineEditWC : public QLineEdit {
	Q_OBJECT

public:
	LineEditWC(QWidget *p = 0) : QLineEdit(p), chk_state(0), init_state(true) 
	{ 
		setContextMenuPolicy(Qt::NoContextMenu); 
		timer = new QTimer(this);
		timer->setSingleShot(true);
		timer->setInterval(2000);
		connect(timer, SIGNAL(timeout()), this, SLOT(chk_clear()));	
	}

	void setInitState(bool s) 
	{ 
		init_state = s; 
		clear();
		if (init_state) {
			setStyleSheet("QLineEdit#wordInput {color: grey;}");
			setText("Enter a word");
			setCursorPosition(0);
		} else {
			setStyleSheet("QLineEdit#wordInput{color: black;}");
		}
	}

	bool initState() { return init_state; }

	virtual void paintEvent(QPaintEvent *ev) 
	{
		QLineEdit::paintEvent(ev);

		QPainter r(this);
		switch (chk_state) {
		case 0:
			r.drawPixmap(size().width()-22, 0, QPixmap());
			break;
		case 1:
			r.drawPixmap(size().width()-22, (size().height()-16)/2, 
			QPixmap(QString(":/pics/tick.png")));
			break;
		case -1:
			r.drawPixmap(size().width()-22, (size().height()-16)/2, 
			QPixmap(QString(":/pics/cross.png")));
			break;
		}
	}

	virtual void mousePressEvent(QMouseEvent *ev)
	{
		if (init_state) 
			setInitState(false);
		else 
			QLineEdit::mousePressEvent(ev);
	}

	virtual void keyPressEvent(QKeyEvent *ev)
	{
		int k = ev->key();
		if (init_state) {
			if ((k >= Qt::Key_A && k <= Qt::Key_Z)) {
				setInitState(false);
				QLineEdit::keyPressEvent(ev);
			}
		} else {
			QLineEdit::keyPressEvent(ev);
		}
	}

	virtual void focusInEvent(QFocusEvent *ev)
	{
		QLineEdit::focusInEvent(ev);
		if (init_state)
			setCursorPosition(0);
	}

private slots:
	void chk_clear() 
	{ 
		chk_state = 0; 
		setStyleSheet("QLineEdit#wordInput {padding-right: 0;}");
	}

public slots:
	void chk(bool v)
	{
		chk_state = v ? 1 : -1;

		chk_state == 1 ?  
			setStyleSheet("QLineEdit { padding-right: 28; border-width: 1px;"
						  "border-style: inset; border-color: darkgreen; }") 
			:
			setStyleSheet("QLineEdit { padding-right: 28; border-width: 1px;"
						  "border-style: inset; border-color: darkred; }");

		timer->start();
	}

private:
	int		chk_state;
	int		init_state;
	QTimer	*timer;
};

#endif

==> spellathon-5.34.tar.gz: spellathon-5.34/src/gui/lineeditwc_widget.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef _LINEEDITWC_WIDGET_H_
#define _LINEEDITWC_WIDGET_H_

#include <QObject>
#include <QLineEdit>

class QTimer;

class LineEditWC : public QLineEdit {
	Q_OBJECT
public:
	LineEditWC(QWidget *p = 0);

	void setInitState(bool s);
	bool initState() const { return init_state; }
private:
	virtual void paintEvent(QPaintEvent *ev);
	virtual void mousePressEvent(QMouseEvent *ev);
	virtual void keyPressEvent(QKeyEvent *ev);
	virtual void focusInEvent(QFocusEvent *ev);
private slots:
	void chk_clear(); 
public slots:
	void chk(bool v);
private:
	int		chk_state;
	int		init_state;
	QTimer	*timer;
};

#endif /* _LINEEDITWC_WIDGET_H_ */
